@@ -190,12 +190,12 @@ class InputApiClient:
         else:
             return [IAM.CalibrationWithContent.from_json(js) for js in json_resp]
 
-    def create_calibration_data(self, calibration: dict, external_id: str
+    def create_calibration_data(self, calibration: IAM.Calibration, external_id: str
                                 ) -> IAM.CalibrationNoContent:
         url = f"{self.host}/v1/inputs/calibration-data"
         js = dict(
             externalId=external_id,
-            calibration=calibration
+            calibration=calibration.to_dict()
         )
         resp = self.session.post(url, json=js, headers=self.headers)
         json_resp = self._raise_on_error(resp).json()
@@ -294,3 +294,31 @@ class InputApiClient:
         resp = self.session.get(base_url, headers=self.headers)
         json_resp = self._raise_on_error(resp).json()
         return [IAM.Request.from_json(js) for js in json_resp]
+
+    def get_datas_for_inputs_by_internal_ids(self, internal_ids: List[str]) -> Mapping[IAM.Input, List[IAM.Data]]:
+        base_url = f"{self.host}/v1/inputs/datas-internal-id"
+        js = internal_ids
+        resp = self.session.get(base_url, json=js, headers=self.headers)
+        json_resp = self._raise_on_error(resp).json()
+
+        new_dict = {}
+        for (k, v) in json_resp:
+            new_key = IAM.Input.from_json(k)
+            new_values = [IAM.Data.from_json(vv) for vv in v]
+            new_dict[new_key] = new_values
+
+        return new_dict
+
+    def get_datas_for_inputs_by_external_ids(self, external_ids: List[str]) -> Mapping[IAM.Input, List[IAM.Data]]:
+        base_url = f"{self.host}/v1/inputs/datas-external-id"
+        js = external_ids
+        resp = self.session.get(base_url, json=js, headers=self.headers)
+        json_resp = self._raise_on_error(resp).json()
+
+        new_dict = {}
+        for (k, v) in json_resp:
+            new_key = IAM.Input.from_json(k)
+            new_values = [IAM.Data.from_json(vv) for vv in v]
+            new_dict[new_key] = new_values
+
+        return new_dict
